@@ -44,21 +44,21 @@ class GraphomalyEstimator(BaseEstimator):
     ----------
     config_file: string, default="graphomaly.yaml"
         user provided configuration file that will overwrite the constructor
-        provided parameters
+        provided parameters.
 
     models_train_all: bool, default=False
-        if `True` performs training on all avalibale models. See
+        if `True`, performs training on all available models. See
         `ModelsLoader` from `graphomaly.models` for a full list.
 
     models_subset: list, default=["PyodIForest", "PyodLOF", "PyodOCSVM"]
         if `models_train_all` is `False`, the list of machine learning models to
-        use for the Graphomaly estimator
+        use for the Graphomaly estimator.
 
     models_ctor_kwargs: dictionary, default=None
-        constructor arguments for each of the selected machine learning models
+        constructor arguments for each of the selected machine learning models.
 
     models_fit_kwargs: dictionary, default=None
-        `fit` arguments for each of the selected machine learning models
+        :meth:`fit` arguments for each of the selected machine learning models.
 
     n_cpus: int, default=1
         number of processors to use when concurrency and parallelism is
@@ -83,7 +83,7 @@ class GraphomalyEstimator(BaseEstimator):
         user provided configuration file
 
     models_train_all: bool
-        whether all avalibale models were used during training
+        whether all available models were used during training
 
     models_subset: list
         subset of machine learning models to use during training
@@ -92,7 +92,7 @@ class GraphomalyEstimator(BaseEstimator):
         constructor arguments used for each of the selected machine learning models
 
     models_fit_kwargs: dictionary
-        `fit` arguments used for each of the selected machine learning models
+        :meth:`fit` arguments used for each of the selected machine learning models
 
     n_cpus: int
         number of processors to use
@@ -101,7 +101,7 @@ class GraphomalyEstimator(BaseEstimator):
         directory where trained models are stored
 
     voting: string
-        voting method to used for perdictions
+        voting method to used for predictions
 
     labels_: ndarray
         resulting labels after ensemble voting
@@ -114,8 +114,8 @@ class GraphomalyEstimator(BaseEstimator):
     models: list
         trained models objects for each method in `models_list`. This will
         include the models that performed best during `GridSearch` if labels
-        were available during `fit`, or the models for all parametrizations
-        if labels were not available during `fit`.
+        were available during :meth:`fit`, or the models for all parametrizations
+        if labels were not available during :meth:`fit`.
 
     models_name: list
         used together with `models` when labels are not available during `GridSearch`
@@ -200,7 +200,7 @@ class GraphomalyEstimator(BaseEstimator):
         Parameters
         ----------
         X: array-like of shape (n_samples, n_features)
-            The raw training dataset consiting of transactions list or graph
+            The raw training dataset consisting of transactions list or graph
 
         y: array-like of shape (n_samples, )
             The ground truth for training dataset.
@@ -208,31 +208,41 @@ class GraphomalyEstimator(BaseEstimator):
         type: string
             Preprocessing steps required. Depending on the input, the possible
             preprocessing actions are:
-            * transactions_to_features (TODO)
-            * graph_to_features
-            * transactions_to_graph_to_features
+
+            * `'transactions_to_features'`: see  :ref:`sec-transaction-list-to-features` (TODO)
+            * `'graph_to_features'`: see :ref:`sec-graph-to-features`
+            * `'transactions_to_graph_to_features'`: combines the operations from
+                :ref:`sec-transaction-list-to-graph` and :ref:`sec-graph-to-features`
 
         Keyword Args: dictionary
             The keyword args contains a dictionary consisting of two entries
+
             * to_graph_args: dictionary
                 Contains fit `kwargs` for `preprocessing.transactions_to_graph`
                 module
             * to_feature_args: dictionary
-                Available key values
-                * algorithms: list, `'egonet'`, `'rwalk'`, `'spectrum'`
-                * algorithms_args: dictionary, '`ctor_args'` and `'fit_args'`
-                    *ctor_args: dictionary
+                Available key values:
+
+                * algorithms: list of strings
+                    Possible elements: `'egonet'`, `'rwalk'`, `'spectrum'`
+                * algorithms_args: dictionary
+                    Possible elements: '`ctor_args'` and `'fit_args'`
+
+                    * ctor_args: dictionary
                         Represents arguments passed to the algorithm's constructor.
-                    *fit_args: dictionary
+                    * fit_args: dictionary
                         Represents options passed to the fit method.
 
         Returns
         -------
-        X: The preprocessed training dataset
+        X: ndarray
+            The preprocessed training dataset.
 
-        y: The preprocessed labels
+        y: ndarray
+            The preprocessed labels.
 
-        G: The graph associated to the raw training dataset
+        G: ndarray
+            The graph associated to the raw training dataset.
 
         See also
         --------
@@ -273,9 +283,11 @@ class GraphomalyEstimator(BaseEstimator):
             y_true_nodes = np.zeros((gXy.number_of_nodes(),), dtype=int)
             nodes_array = np.array(gXy.nodes())
             for (i, j, label) in gXy.edges.data("labels"):
-                if label == 1:
+                if label >= 1:
                     index = np.where(nodes_array == i)[0][0]
                     y_true_nodes[index] = 1
+                    index = np.where(nodes_array == j)[0][0]
+                    y_true_nodes[index] = 1
 
             # sort on node id
             ii = np.argsort(nodes_array)
@@ -301,7 +313,7 @@ class GraphomalyEstimator(BaseEstimator):
                 features_names_in = rwalk.feature_names_in_
             elif algo == "spectrum":
                 spectrum = SpectrumFeatures(**ctor_args)
-                spectrum.fit_transform(G, **fit_args)
+                features = spectrum.fit_transform(G, **fit_args)
                 features_names_in = spectrum.feature_names_in_
             all_features.append(features)
             self.feature_names_in_.append(features_names_in)
@@ -309,15 +321,15 @@ class GraphomalyEstimator(BaseEstimator):
         return np.concatenate(all_features, axis=1)
 
     def _get_params(self, algorithm, n_features):
-        if algorithm not in self.models_ctor_kwargs:
-            model_kwargs = {}
-        else:
-            model_kwargs = self.models_ctor_kwargs[algorithm]
+        model_kwargs = {}
+        if self.models_ctor_kwargs is not None:
+            if algorithm in self.models_ctor_kwargs:
+                model_kwargs = self.models_ctor_kwargs[algorithm]
 
-        if algorithm not in self.models_fit_kwargs:
-            fit_kwargs = {}
-        else:
-            fit_kwargs = self.models_fit_kwargs[algorithm]
+        fit_kwargs = {}
+        if self.models_fit_kwargs is not None:
+            if algorithm in self.models_fit_kwargs:
+                fit_kwargs = self.models_fit_kwargs[algorithm]
 
         # Setting the correct number of decoder neurons after preprocessing.
         if "decoder_neurons" in model_kwargs:
@@ -353,8 +365,9 @@ class GraphomalyEstimator(BaseEstimator):
 
         See also
         --------
-        tests.test_synthetic: example of performing fit on synthetic
-        generated data on a small subset of methods and parameters list.
+        tests.test_synthetic:
+            example of performing fit on synthetic
+            generated data on a small subset of methods and parameters list.
         """
         self.tune(X, y)
 
@@ -378,7 +391,8 @@ class GraphomalyEstimator(BaseEstimator):
 
         Returns
         -------
-        y: The predicted labels
+        y: array-like of shape (n_samples, )
+            The predicted labels
 
         See also
         --------
@@ -404,12 +418,13 @@ class GraphomalyEstimator(BaseEstimator):
 
         Returns
         -------
-        y: The predicted labels
+        y: array-like of shape (n_samples, )
+            The predicted labels
 
         See also
         --------
-        tests.test_synthetic_voting: example of trying all available
-        voting methods
+        tests.test_synthetic_voting:
+            example of trying all available voting methods
         """
         if voting:
             self.voting = voting
@@ -441,8 +456,9 @@ class GraphomalyEstimator(BaseEstimator):
 
         See also
         --------
-        tests.test_synthetic_gridsearch: example of performing parameter tuning
-        on a small subset of methods and parameters list.
+        tests.test_synthetic_gridsearch:
+            example of performing parameter tuning
+            on a small subset of methods and parameters list.
         """
         for algorithm in self.models_list:
             model_kwargs, fit_kwargs = self._get_params(algorithm, X.shape[1])
@@ -475,7 +491,7 @@ class GraphomalyEstimator(BaseEstimator):
                 self.models.append(search.best_estimator_)
 
                 logging.info(
-                    f"Best params for {algorithm}[BA={search.best_score_}]: "
+                    f"Best params for {algorithm}[{search.best_score_}]: "
                     f"{search.best_params_}"
                 )
 
